==> hsqldb_2.3.3+dfsg2.orig.tar.xz: hsqldb-2.3.3/hsqldb/src/org/hsqldb/lib/InputStreamWrapper.java <==
/* Copyright (c) 2001-2014, The HSQL Development Group
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name of the HSQL Development Group nor the names of its
 * contributors may be used to endorse or promote products derived from this
 * software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL HSQL DEVELOPMENT GROUP, HSQLDB.ORG,
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


package org.hsqldb.lib;

import java.io.IOException;
import java.io.InputStream;

/**
 * @author Fred Toussi (fredt@users dot sourceforge.net)
 * @version 2.2.9
 * @since 2.2.8
 */
public class InputStreamWrapper implements InputStreamInterface {

    InputStream is;
    long        limitSize   = -1;
    long        fetchedSize = 0;

    public InputStreamWrapper(InputStream is) {
        this.is = is;
    }

    public int read() throws IOException {

        if (fetchedSize == limitSize) {
            return -1;
        }

        int byteread = is.read();

        if (byteread < 0) {
            if (limitSize == -1) {
                return -1;
            } else {
                throw new IOException("stream not reached the end"
                                      + fetchedSize + " " + limitSize);
            }
        }

        fetchedSize++;

        return byteread;
    }

    public int read(byte bytes[]) throws IOException {
        return read(bytes, 0, bytes.length);
    }

    public int read(byte bytes[], int offset, int length) throws IOException {

        if (fetchedSize == limitSize) {
            return -1;
        }

        if (limitSize >= 0 && limitSize - fetchedSize < length) {
            length = (int) (limitSize - fetchedSize);
        }

        int count = is.read(bytes, offset, length);

        if (count < 0) {
            if (limitSize == -1) {
                return -1;
            } else {
                throw new IOException("stream not reached the end"
                                      + fetchedSize + " " + limitSize);
            }
        }

        fetchedSize += count;

        return count;
    }

    public long skip(long count) throws IOException {
        return is.skip(count);
    }

    public int available() throws IOException {
        return is.available();
    }

    public void close() throws IOException {
        is.close();
    }

    public void setSizeLimit(long count) {
        limitSize = count;
    }

    public long getSizeLimit() {
        return limitSize;
    }
}

==> hsqldb_2.4.0.orig.tar.xz: hsqldb-2.4.0/hsqldb/src/org/hsqldb/lib/InputStreamWrapper.java <==
/* Copyright (c) 2001-2016, The HSQL Development Group
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name of the HSQL Development Group nor the names of its
 * contributors may be used to endorse or promote products derived from this
 * software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL HSQL DEVELOPMENT GROUP, HSQLDB.ORG,
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


package org.hsqldb.lib;

import java.io.IOException;
import java.io.InputStream;

/**
 * @author Fred Toussi (fredt@users dot sourceforge.net)
 * @version 2.2.9
 * @since 2.2.8
 */
public class InputStreamWrapper implements InputStreamInterface {

    InputStream is;
    long        limitSize   = -1;
    long        fetchedSize = 0;

    public InputStreamWrapper(InputStream is) {
        this.is = is;
    }

    public int read() throws IOException {

        if (fetchedSize == limitSize) {
            return -1;
        }

        int byteread = is.read();

        if (byteread < 0) {
            if (limitSize == -1) {
                return -1;
            } else {
                throw new IOException("stream not reached the end"
                                      + fetchedSize + " " + limitSize);
            }
        }

        fetchedSize++;

        return byteread;
    }

    public int read(byte[] bytes) throws IOException {
        return read(bytes, 0, bytes.length);
    }

    public int read(byte[] bytes, int offset, int length) throws IOException {

        if (fetchedSize == limitSize) {
            return -1;
        }

        if (limitSize >= 0 && limitSize - fetchedSize < length) {
            length = (int) (limitSize - fetchedSize);
        }

        int count = is.read(bytes, offset, length);

        if (count < 0) {
            if (limitSize == -1) {
                return -1;
            } else {
                throw new IOException("stream not reached the end"
                                      + fetchedSize + " " + limitSize);
            }
        }

        fetchedSize += count;

        return count;
    }

    public long skip(long count) throws IOException {
        return is.skip(count);
    }

    public int available() throws IOException {
        return is.available();
    }

    public void close() throws IOException {
        is.close();
    }

    public void setSizeLimit(long count) {
        limitSize = count;
    }

    public long getSizeLimit() {
        return limitSize;
    }
}
